==> projectcenter.app_0.5.0~20080704.orig.tar.gz: ProjectCenter-0.5.0/PCInfoController.m <==
/*
   GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html

   Copyright (C) 2001 Free Software Foundation

   This file is part of GNUstep.

   This application is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This application is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/

#include <ProjectCenter/ProjectCenter.h>

#include "PCInfoController.h"

@implementation PCInfoController

- (id)init
{
  if ((self = [super init]))
    {
      NSString *file;

      file = [[NSBundle mainBundle] pathForResource:@"Info-gnustep" 
	ofType:@"plist"];

      infoDict = [NSDictionary dictionaryWithContentsOfFile:file];
      RETAIN(infoDict);
    }

  return self;
}

- (void)dealloc
{
  RELEASE(infoDict);

  if (infoWindow) 
    {
      RELEASE(infoWindow);
    }

  [super dealloc];
}

- (void)showInfoWindow:(id)sender
{
  if ([NSBundle loadNibNamed:@"Info" owner:self] == NO)
    {
//	PCLogError(self, @"error loading Menu NIB file!");
	return;
    }
		
/*#if defined(GNUSTEP)
  if (!infoWindow)
    {
      infoWindow = [[GSInfoPanel alloc] initWithDictionary:infoDict];
    }

  [infoWindow setTitle:@"Info"];
  [infoWindow center];
  [infoWindow makeKeyAndOrderFront:self];
#else
  NSRunAlertPanel(@"Info",
		  @"OPENSTEP has no support for GSInfoPanel",
		  @"OK",nil,nil,nil);
#endif*/
}

@end

==> projectcenter.app_0.6.1.orig.tar.gz: ProjectCenter-0.6.1/PCInfoController.m <==
/*
   GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html

   Copyright (C) 2001 Free Software Foundation

   This file is part of GNUstep.

   This application is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This application is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/

#import <ProjectCenter/ProjectCenter.h>

#import "PCInfoController.h"

@implementation PCInfoController

- (id)init
{
  if ((self = [super init]))
    {
      NSString *file;

      file = [[NSBundle mainBundle] pathForResource:@"Info-gnustep" 
	ofType:@"plist"];

      infoDict = [NSDictionary dictionaryWithContentsOfFile:file];
      RETAIN(infoDict);
    }

  return self;
}

- (void)dealloc
{
  RELEASE(infoDict);

  if (infoWindow) 
    {
      RELEASE(infoWindow);
    }

  [super dealloc];
}

- (void)showInfoWindow:(id)sender
{
  if ([NSBundle loadNibNamed:@"Info" owner:self] == NO)
    {
//	PCLogError(self, @"error loading Menu NIB file!");
	return;
    }

  [infoWindow makeKeyAndOrderFront:self];
  [versionField setStringValue:[NSString stringWithFormat:@"Version %@", [infoDict objectForKey:@"ApplicationRelease"]]];
		
/*#if defined(GNUSTEP)
  if (!infoWindow)
    {
      infoWindow = [[GSInfoPanel alloc] initWithDictionary:infoDict];
    }

  [infoWindow setTitle:@"Info"];
  [infoWindow center];
  [infoWindow makeKeyAndOrderFront:self];
#else
  NSRunAlertPanel(@"Info",
		  @"OPENSTEP has no support for GSInfoPanel",
		  @"OK",nil,nil,nil);
#endif*/
}

@end
